@@ -9,14 +9,30 @@ try:
 except:
     try:
         from network_destination import NetworkDestination
-    except:
-        pass
+    except Exception as e:
+        raise ValueError(e)
 
 ################################################################################
 #         Cluster object for clustering flows per network destination          #
 ################################################################################
 
 class Cluster(object):
+    """Cluster object for clustering flows by network destination
+
+        Attributes
+        ----------
+        samples : np.array of shape=(n_samples,)
+            Samples used to fit Cluster
+
+        counter : int
+            Counter for total number of NetworkDestinations generated
+
+        dict_destination : dict
+            Dicationary of (dst IP, dst port) -> NetworkDestination
+
+        dict_certificate : dict
+            Dicationary of TLS certificate -> NetworkDestination
+    """
 
     def __init__(self, load=None):
         """Cluster flows by network destinations
@@ -69,8 +85,8 @@ class Cluster(object):
         for sample, label in zip(X, y):
 
             # Extract values
-            certificate = sample.certificate()
-            destination = sample.destination()
+            certificate = sample.certificate
+            destination = sample.destination
 
             # Get the number of matching clusters
             clusters = [self.dict_certificate.get(certificate),
@@ -151,8 +167,8 @@ class Cluster(object):
                 if no cluster could be matched.
             """
         # Get matching cluster or -1
-        return self.dict_destination.get(X.destination(),
-               self.dict_certificate.get(X.certificate(),
+        return self.dict_destination.get(X.destination,
+               self.dict_certificate.get(X.certificate,
                NetworkDestination(-1))).identifier
 
     def fit_predict(self, X):
